summaryrefslogtreecommitdiff
path: root/gcc
diff options
context:
space:
mode:
authormeissner <meissner@138bc75d-0d04-0410-961f-82ee72b054a4>1992-05-07 06:41:20 +0000
committermeissner <meissner@138bc75d-0d04-0410-961f-82ee72b054a4>1992-05-07 06:41:20 +0000
commitb550e0588e54efcea40f213bc2a92149514efa19 (patch)
treea1f7bb72e5b4c58a657fc844c6b19930ba5849d2 /gcc
parentf0e22b4ea622717f357a44f04d568461de30b47d (diff)
downloadgcc-b550e0588e54efcea40f213bc2a92149514efa19.tar.gz
*** empty log message ***
git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@929 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc')
-rw-r--r--gcc/config/i386/osfrose.h2
-rw-r--r--gcc/config/mips/mips.h4
-rw-r--r--gcc/halfpic.c2
-rw-r--r--gcc/loop.c8
-rw-r--r--gcc/mips-tfile.c20
5 files changed, 18 insertions, 18 deletions
diff --git a/gcc/config/i386/osfrose.h b/gcc/config/i386/osfrose.h
index 0bcbaa04c61..82d9ddb26fc 100644
--- a/gcc/config/i386/osfrose.h
+++ b/gcc/config/i386/osfrose.h
@@ -124,7 +124,7 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */
#define HAVE_ATEXIT
/* Define this macro meaning that gcc should find the library 'libgcc.a'
- by hand, rather than passing the argeument '-lgcc' to tell the linker
+ by hand, rather than passing the argument '-lgcc' to tell the linker
to do the search */
#define LINK_LIBGCC_SPECIAL
diff --git a/gcc/config/mips/mips.h b/gcc/config/mips/mips.h
index 4876ef7294d..7463acf7797 100644
--- a/gcc/config/mips/mips.h
+++ b/gcc/config/mips/mips.h
@@ -2882,7 +2882,7 @@ while (0)
pattern $L[a-z].*. The machine independent portion of GCC creates
labels matching: $L[A-Z][0-9]+ and $L[0-9]+.
- LM[0-9]+ Sillicon graphics/ECOFF stabs label before each stmt.
+ LM[0-9]+ Silicon Graphics/ECOFF stabs label before each stmt.
$Lb[0-9]+ Begin blocks for MIPS debug support
$Lc[0-9]+ Label for use in s<xx> operation.
$Le[0-9]+ End blocks for MIPS debug support
@@ -2939,7 +2939,7 @@ while (0)
#define ASM_OUTPUT_COMMON(STREAM, NAME, SIZE, ROUNDED) \
mips_declare_object (STREAM, NAME, "\n\t.comm\t", ",%u\n", (ROUNDED))
-/* This says how to define a local common symbol (ie, not visable to
+/* This says how to define a local common symbol (ie, not visible to
linker). */
#define ASM_OUTPUT_LOCAL(STREAM, NAME, SIZE, ROUNDED) \
diff --git a/gcc/halfpic.c b/gcc/halfpic.c
index 817dc21b7c0..fdbaccd2ee0 100644
--- a/gcc/halfpic.c
+++ b/gcc/halfpic.c
@@ -20,7 +20,7 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */
/* The OSF/rose half-pic model assumes that the non-library code does
not need to have full PIC (position independent code), but rather,
that pointers to external references are put into the data section
- and derefenced as normal pointers. References to static data does
+ and dereferenced as normal pointers. References to static data does
not need to be PIC-ized.
Another optimization is to have the compiler know what symbols are
diff --git a/gcc/loop.c b/gcc/loop.c
index cd01b250f3f..3a5b9cf49a8 100644
--- a/gcc/loop.c
+++ b/gcc/loop.c
@@ -119,7 +119,7 @@ static rtx loop_continue;
is set during the loop being scanned.
During code motion, a negative value indicates a reg that has been
made a candidate; in particular -2 means that it is an candidate that
- we know is equal to a constant and -1 means that it is an condidate
+ we know is equal to a constant and -1 means that it is an candidate
not known equal to a constant.
After code motion, regs moved have 0 (which is accurate now)
while the failed candidates have the original number of times set.
@@ -3843,7 +3843,7 @@ strength_reduce (scan_start, end, loop_top, insn_count,
like it can be used to eliminate a biv, but the resulting insn
isn't valid. This can happen, for example, on the 88k, where a
JUMP_INSN can compare a register only with zero. Attempts to
- replace it with a comapare with a constant will fail.
+ replace it with a compare with a constant will fail.
Note that in cases where this call fails, we may have replaced some
of the occurrences of the biv with a giv, but no harm was done in
@@ -4098,7 +4098,7 @@ record_biv (v, insn, dest_reg, inc_val, mult_val,
/* Set initial value to the reg itself. */
bl->initial_value = dest_reg;
- /* We haven't seen the intializing insn yet */
+ /* We haven't seen the initializing insn yet */
bl->init_insn = 0;
bl->init_set = 0;
bl->initial_test = 0;
@@ -4808,7 +4808,7 @@ general_induction_var (x, src_reg, add_val, mult_val)
We will canonicalize it to be of the form
(plus (mult (BIV) (invar_1))
(invar_2))
- with possibile degeneracies.
+ with possible degeneracies.
The invariant expressions must each be of a form that can be used as a
machine operand. We surround then with a USE rtx (a hack, but localized
diff --git a/gcc/mips-tfile.c b/gcc/mips-tfile.c
index a8ffb559805..d50e418b603 100644
--- a/gcc/mips-tfile.c
+++ b/gcc/mips-tfile.c
@@ -193,7 +193,7 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */
stLocal -- local variable
stLabel -- label
stProc -- External Procedure
- stBlock -- beginnning of block
+ stBlock -- beginning of block
stEnd -- end (of anything)
stMember -- member (of anything)
stTypedef -- type definition
@@ -262,7 +262,7 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */
Procedures Tables 384 1 52
Local Symbols 436 16 192
Optimization Symbols 0 0 0
- Auxilary Symbols 628 39 156
+ Auxiliary Symbols 628 39 156
Local Strings 784 80 80
External Strings 864 144 144
File Tables 1008 2 144
@@ -723,7 +723,7 @@ extern int errno; /* MIPS errno.h doesn't declare this */
(isalnum (ch) || (ch) == '_' || (ch) == '.' || (ch) == '$')
-/* Redefination of of storage classes as an enumeration for better
+/* Redefinition of of storage classes as an enumeration for better
debugging. */
typedef enum sc {
@@ -763,7 +763,7 @@ typedef enum st {
st_Local = stLocal, /* local variable */
st_Label = stLabel, /* label */
st_Proc = stProc, /* " " Procedure */
- st_Block = stBlock, /* beginnning of block */
+ st_Block = stBlock, /* beginning of block */
st_End = stEnd, /* end (of anything) */
st_Member = stMember, /* member (of anything - struct/union/enum */
st_Typedef = stTypedef, /* type definition */
@@ -775,7 +775,7 @@ typedef enum st {
st_Str = stStr, /* string */
st_Number = stNumber, /* pure number (ie. 4 NOR 2+2) */
st_Expr = stExpr, /* 2+2 vs. 4 */
- st_Type = stType, /* post-coersion SER */
+ st_Type = stType, /* post-coercion SER */
st_Max = stMax /* max type+1 */
} st_t;
@@ -1744,7 +1744,7 @@ extern char *sys_siglist[NSIG + 1];
do...... */
typedef struct _pseudo_ops {
- const char *name; /* pseduo-op in ascii */
+ const char *name; /* pseudo-op in ascii */
int len; /* length of name to compare */
void (*func) __proto((const char *)); /* function to handle line */
} pseudo_ops_t;
@@ -2120,7 +2120,7 @@ add_ext_symbol (str_start, str_end_p1, type, storage, value, indx, ifd)
STATIC symint_t
add_aux_sym_symint (aux_word)
- symint_t aux_word; /* auxilary information word */
+ symint_t aux_word; /* auxiliary information word */
{
register AUXU *aux_ptr;
register efdr_t *file_ptr = cur_file_ptr;
@@ -3147,7 +3147,7 @@ parse_def (name_start)
/* If this is a function, ignore it, so that we don't get
two entries (one from the .ent, and one for the .def
- that preceedes it). Save the type information so that
+ that precedes it). Save the type information so that
the end block can properly add it after the begin block
index. For MIPS knows what reason, we must strip off
the function type at this point. */
@@ -3185,7 +3185,7 @@ parse_def (name_start)
/* If the value is not an integer value, it must be the
name of a static or global item. Look up the name in
- the orignal symbol table to pick up the storage
+ the original symbol table to pick up the storage
class, symbol type, etc. */
else
{
@@ -3369,7 +3369,7 @@ parse_def (name_start)
/* Members of structures and unions that aren't bitfields, need
to adjust the value from a byte offset to a bit offset.
Members of enumerations do not have the value adjusted, and
- can be distinquished by index == indexNil. For enumerations,
+ can be distinguished by index == indexNil. For enumerations,
update the maximum enumeration value. */
case st_Member: